package org.cytoscape.task.select;

/*
 * #%L
 * Cytoscape Core Task API (core-task-api)
 * $Id:$
 * $HeadURL:$
 * %%
 * Copyright (C) 2006 - 2013 The Cytoscape Consortium
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 2.1 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */

import java.io.File;

import org.cytoscape.model.CyNetwork;
import org.cytoscape.task.NetworkTaskFactory;
import org.cytoscape.work.TaskIterator;

/**
 * This interface provides a task iterator for selecting items based on a file.
 * The file should be a simple text file with one identifier per line.
 * @CyAPI.Api.Interface
 * @CyAPI.InModule core-task-api
 */
public interface SelectFromFileListTaskFactory extends NetworkTaskFactory {
	
	/**
	 * Creates a task iterator for selecting items of a network based on a file.
	 * @param network The target network to select nodes and edges from.
	 * @param file The file that has the selection list in.
 	 * The file should be a simple text file with one identifier per line.
	 * @return a task iterator of type {@link TaskIterator}.
	 */
	TaskIterator createTaskIterator(CyNetwork network, final File file);

}
