package org.cytoscape.event;

/*
 * #%L
 * Cytoscape Event API (event-api)
 * $Id:$
 * $HeadURL:$
 * %%
 * Copyright (C) 2008 - 2013 The Cytoscape Consortium
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 2.1 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */


import org.junit.Test;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertEquals;
import java.util.Collection;
import java.util.List;
import java.util.ArrayList;

/**
 */
public class AbstractCyPayloadEventTest {

	private static class TestEvent<T,P> extends AbstractCyPayloadEvent<T,P> {
		TestEvent(T src, Class<?> c, Collection<P> payload) {
			super(src,c,payload);
		}
	}


	@Test
	public void testGetPayload() {
		List<String> l = new ArrayList<String>();
		l.add("homer");
		l.add("marge");
		Object source = new Object(); 
		TestEvent<Object,String> e = new TestEvent<Object,String>(source,Object.class,l);
		Collection<String> payload = e.getPayloadCollection();
		assertEquals(2,payload.size());
		assertTrue(payload.contains("homer"));
		assertTrue(payload.contains("marge"));
		assertFalse(payload.contains("bart"));
	}

	@Test(expected=NullPointerException.class)
	public void testGetPayloadNull() {
		Object source = new Object(); 
		TestEvent<Object,String> e = new TestEvent<Object,String>(source,Object.class,null);
	}

	@Test
	public void testGetEmptyPayload() {
		List<String> l = new ArrayList<String>();
		Object source = new Object(); 
		TestEvent<Object,String> e = new TestEvent<Object,String>(source,Object.class,l);
		Collection<String> payload = e.getPayloadCollection();
		assertEquals(0,payload.size());
		assertFalse(payload.contains("bart"));
	}
	
	@Test(expected=UnsupportedOperationException.class)
	public void testCantModifyPayload() {
		List<String> l = new ArrayList<String>();
		l.add("homer");
		l.add("marge");
		Object source = new Object(); 
		TestEvent<Object,String> e = new TestEvent<Object,String>(source,Object.class,l);
		Collection<String> payload = e.getPayloadCollection();
		payload.add("something");
	}
}
