package org.cytoscape.util.swing;

import java.awt.Font;

/**
 * Interface that provides constants for simple icons that can be used by Cytoscape and third party apps in order to
 * create a more consistent GUI.
 * <br />
 * The icons are provided by <a href="http://fortawesome.github.io/Font-Awesome/">Font Awesome</a>
 * <br />
 * These icons are set as text (not images) to buttons, labels, etc. So always set the ICON constant as text and
 * the font provided by {@link #getIconFont(float)} to the UI component.
 * <br />
 * Example:
 * <br />
 * <code>JButton button = new JButton(IconManager.ICON_CAMERA);
 * button.setFont(cyServiceRegistrar.getService(IconManager.class).getIconFont(14.0f));</code>
 * 
 * @CyAPI.Api.Interface 
 * @CyAPI.InModule swing-util-api
 */
public interface IconManager {
	
	/**
	 * Returns the font that renders the text as an icon.
	 * @see <a href="http://fortawesome.github.io/Font-Awesome/icons/">Font Awesome Icons</a>
	 * @param size The font size.
	 * @return
	 */
	Font getIconFont(float size);
	
	static final String ICON_ADJUST = "\uf042";
	static final String ICON_ADN = "\uf170";
	static final String ICON_ALIGN_CENTER = "\uf037";
	static final String ICON_ALIGN_JUSTIFY = "\uf039";
	static final String ICON_ALIGN_LEFT = "\uf036";
	static final String ICON_ALIGN_RIGHT = "\uf038";
	static final String ICON_AMBULANCE = "\uf0f9";
	static final String ICON_ANCHOR = "\uf13d";
	static final String ICON_ANDROID = "\uf17b";
	static final String ICON_ANGELLIST = "\uf209";
	static final String ICON_ANGLE_DOUBLE_DOWN = "\uf103";
	static final String ICON_ANGLE_DOUBLE_LEFT = "\uf100";
	static final String ICON_ANGLE_DOUBLE_RIGHT = "\uf101";
	static final String ICON_ANGLE_DOUBLE_UP = "\uf102";
	static final String ICON_ANGLE_DOWN = "\uf107";
	static final String ICON_ANGLE_LEFT = "\uf104";
	static final String ICON_ANGLE_RIGHT = "\uf105";
	static final String ICON_ANGLE_UP = "\uf106";
	static final String ICON_APPLE = "\uf179";
	static final String ICON_ARCHIVE = "\uf187";
	static final String ICON_AREA_CHART = "\uf1fe";
	static final String ICON_ARROW_CIRCLE_DOWN = "\uf0ab";
	static final String ICON_ARROW_CIRCLE_LEFT = "\uf0a8";
	static final String ICON_ARROW_CIRCLE_O_DOWN = "\uf01a";
	static final String ICON_ARROW_CIRCLE_O_LEFT = "\uf190";
	static final String ICON_ARROW_CIRCLE_O_RIGHT = "\uf18e";
	static final String ICON_ARROW_CIRCLE_O_UP = "\uf01b";
	static final String ICON_ARROW_CIRCLE_RIGHT = "\uf0a9";
	static final String ICON_ARROW_CIRCLE_UP = "\uf0aa";
	static final String ICON_ARROW_DOWN = "\uf063";
	static final String ICON_ARROW_LEFT = "\uf060";
	static final String ICON_ARROW_RIGHT = "\uf061";
	static final String ICON_ARROW_UP = "\uf062";
	static final String ICON_ARROWS = "\uf047";
	static final String ICON_ARROWS_ALT = "\uf0b2";
	static final String ICON_ARROWS_H = "\uf07e";
	static final String ICON_ARROWS_V = "\uf07d";
	static final String ICON_ASTERISK = "\uf069";
	static final String ICON_AT = "\uf1fa";
	static final String ICON_AUTOMOBILE = "\uf1b9";
	static final String ICON_BACKWARD = "\uf04a";
	static final String ICON_BAN = "\uf05e";
	static final String ICON_BANK = "\uf19c";
	static final String ICON_BAR_CHART = "\uf080";
	static final String ICON_BAR_CHART_O = "\uf080";
	static final String ICON_BARCODE = "\uf02a";
	static final String ICON_BARS = "\uf0c9";
	static final String ICON_BED = "\uf236";
	static final String ICON_BEER = "\uf0fc";
	static final String ICON_BEHANCE = "\uf1b4";
	static final String ICON_BEHANCE_SQUARE = "\uf1b5";
	static final String ICON_BELL = "\uf0f3";
	static final String ICON_BELL_O = "\uf0a2";
	static final String ICON_BELL_SLASH = "\uf1f6";
	static final String ICON_BELL_SLASH_O = "\uf1f7";
	static final String ICON_BICYCLE = "\uf206";
	static final String ICON_BINOCULARS = "\uf1e5";
	static final String ICON_BIRTHDAY_CAKE = "\uf1fd";
	static final String ICON_BITBUCKET = "\uf171";
	static final String ICON_BITBUCKET_SQUARE = "\uf172";
	static final String ICON_BITCOIN = "\uf15a";
	static final String ICON_BOLD = "\uf032";
	static final String ICON_BOLT = "\uf0e7";
	static final String ICON_BOMB = "\uf1e2";
	static final String ICON_BOOK = "\uf02d";
	static final String ICON_BOOKMARK = "\uf02e";
	static final String ICON_BOOKMARK_O = "\uf097";
	static final String ICON_BRIEFCASE = "\uf0b1";
	static final String ICON_BTC = "\uf15a";
	static final String ICON_BUG = "\uf188";
	static final String ICON_BUILDING = "\uf1ad";
	static final String ICON_BUILDING_O = "\uf0f7";
	static final String ICON_BULLHORN = "\uf0a1";
	static final String ICON_BULLSEYE = "\uf140";
	static final String ICON_BUS = "\uf207";
	static final String ICON_BUYSELLADS = "\uf20d";
	static final String ICON_CAB = "\uf1ba";
	static final String ICON_CALCULATOR = "\uf1ec";
	static final String ICON_CALENDAR = "\uf073";
	static final String ICON_CALENDAR_O = "\uf133";
	static final String ICON_CAMERA = "\uf030";
	static final String ICON_CAMERA_RETRO = "\uf083";
	static final String ICON_CAR = "\uf1b9";
	static final String ICON_CARET_DOWN = "\uf0d7";
	static final String ICON_CARET_LEFT = "\uf0d9";
	static final String ICON_CARET_RIGHT = "\uf0da";
	static final String ICON_CARET_SQUARE_O_DOWN = "\uf150";
	static final String ICON_CARET_SQUARE_O_LEFT = "\uf191";
	static final String ICON_CARET_SQUARE_O_RIGHT = "\uf152";
	static final String ICON_CARET_SQUARE_O_UP = "\uf151";
	static final String ICON_CARET_UP = "\uf0d8";
	static final String ICON_CART_ARROW_DOWN = "\uf218";
	static final String ICON_CART_PLUS = "\uf217";
	static final String ICON_CC = "\uf20a";
	static final String ICON_CC_AMEX = "\uf1f3";
	static final String ICON_CC_DISCOVER = "\uf1f2";
	static final String ICON_CC_MASTERCARD = "\uf1f1";
	static final String ICON_CC_PAYPAL = "\uf1f4";
	static final String ICON_CC_STRIPE = "\uf1f5";
	static final String ICON_CC_VISA = "\uf1f0";
	static final String ICON_CERTIFICATE = "\uf0a3";
	static final String ICON_CHAIN = "\uf0c1";
	static final String ICON_CHAIN_BROKEN = "\uf127";
	static final String ICON_CHECK = "\uf00c";
	static final String ICON_CHECK_CIRCLE = "\uf058";
	static final String ICON_CHECK_CIRCLE_O = "\uf05d";
	static final String ICON_CHECK_SQUARE = "\uf14a";
	static final String ICON_CHECK_SQUARE_O = "\uf046";
	static final String ICON_CHEVRON_CIRCLE_DOWN = "\uf13a";
	static final String ICON_CHEVRON_CIRCLE_LEFT = "\uf137";
	static final String ICON_CHEVRON_CIRCLE_RIGHT = "\uf138";
	static final String ICON_CHEVRON_CIRCLE_UP = "\uf139";
	static final String ICON_CHEVRON_DOWN = "\uf078";
	static final String ICON_CHEVRON_LEFT = "\uf053";
	static final String ICON_CHEVRON_RIGHT = "\uf054";
	static final String ICON_CHEVRON_UP = "\uf077";
	static final String ICON_CHILD = "\uf1ae";
	static final String ICON_CIRCLE = "\uf111";
	static final String ICON_CIRCLE_O = "\uf10c";
	static final String ICON_CIRCLE_O_NOTCH = "\uf1ce";
	static final String ICON_CIRCLE_THIN = "\uf1db";
	static final String ICON_CLIPBOARD = "\uf0ea";
	static final String ICON_CLOCK_O = "\uf017";
	static final String ICON_CLOSE = "\uf00d";
	static final String ICON_CLOUD = "\uf0c2";
	static final String ICON_CLOUD_DOWNLOAD = "\uf0ed";
	static final String ICON_CLOUD_UPLOAD = "\uf0ee";
	static final String ICON_CNY = "\uf157";
	static final String ICON_CODE = "\uf121";
	static final String ICON_CODE_FORK = "\uf126";
	static final String ICON_CODEPEN = "\uf1cb";
	static final String ICON_COFFEE = "\uf0f4";
	static final String ICON_COG = "\uf013";
	static final String ICON_COGS = "\uf085";
	static final String ICON_COLUMNS = "\uf0db";
	static final String ICON_COMMENT = "\uf075";
	static final String ICON_COMMENT_O = "\uf0e5";
	static final String ICON_COMMENTS = "\uf086";
	static final String ICON_COMMENTS_O = "\uf0e6";
	static final String ICON_COMPASS = "\uf14e";
	static final String ICON_COMPRESS = "\uf066";
	static final String ICON_CONNECTDEVELOP = "\uf20e";
	static final String ICON_COPY = "\uf0c5";
	static final String ICON_COPYRIGHT = "\uf1f9";
	static final String ICON_CREDIT_CARD = "\uf09d";
	static final String ICON_CROP = "\uf125";
	static final String ICON_CROSSHAIRS = "\uf05b";
	static final String ICON_CSS3 = "\uf13c";
	static final String ICON_CUBE = "\uf1b2";
	static final String ICON_CUBES = "\uf1b3";
	static final String ICON_CUT = "\uf0c4";
	static final String ICON_CUTLERY = "\uf0f5";
	static final String ICON_DASHBOARD = "\uf0e4";
	static final String ICON_DASHCUBE = "\uf210";
	static final String ICON_DATABASE = "\uf1c0";
	static final String ICON_DEDENT = "\uf03b";
	static final String ICON_DELICIOUS = "\uf1a5";
	static final String ICON_DESKTOP = "\uf108";
	static final String ICON_DEVIANTART = "\uf1bd";
	static final String ICON_DIAMOND = "\uf219";
	static final String ICON_DIGG = "\uf1a6";
	static final String ICON_DOLLAR = "\uf155";
	static final String ICON_DOT_CIRCLE_O = "\uf192";
	static final String ICON_DOWNLOAD = "\uf019";
	static final String ICON_DRIBBBLE = "\uf17d";
	static final String ICON_DROPBOX = "\uf16b";
	static final String ICON_DRUPAL = "\uf1a9";
	static final String ICON_EDIT = "\uf044";
	static final String ICON_EJECT = "\uf052";
	static final String ICON_ELLIPSIS_H = "\uf141";
	static final String ICON_ELLIPSIS_V = "\uf142";
	static final String ICON_EMPIRE = "\uf1d1";
	static final String ICON_ENVELOPE = "\uf0e0";
	static final String ICON_ENVELOPE_O = "\uf003";
	static final String ICON_ENVELOPE_SQUARE = "\uf199";
	static final String ICON_ERASER = "\uf12d";
	static final String ICON_EUR = "\uf153";
	static final String ICON_EURO = "\uf153";
	static final String ICON_EXCHANGE = "\uf0ec";
	static final String ICON_EXCLAMATION = "\uf12a";
	static final String ICON_EXCLAMATION_CIRCLE = "\uf06a";
	static final String ICON_EXCLAMATION_TRIANGLE = "\uf071";
	static final String ICON_EXPAND = "\uf065";
	static final String ICON_EXTERNAL_LINK = "\uf08e";
	static final String ICON_EXTERNAL_LINK_SQUARE = "\uf14c";
	static final String ICON_EYE = "\uf06e";
	static final String ICON_EYE_SLASH = "\uf070";
	static final String ICON_EYEDROPPER = "\uf1fb";
	static final String ICON_FACEBOOK = "\uf09a";
	static final String ICON_FACEBOOK_F = "\uf09a";
	static final String ICON_FACEBOOK_OFFICIAL = "\uf230";
	static final String ICON_FACEBOOK_SQUARE = "\uf082";
	static final String ICON_FAST_BACKWARD = "\uf049";
	static final String ICON_FAST_FORWARD = "\uf050";
	static final String ICON_FAX = "\uf1ac";
	static final String ICON_FEMALE = "\uf182";
	static final String ICON_FIGHTER_JET = "\uf0fb";
	static final String ICON_FILE = "\uf15b";
	static final String ICON_FILE_ARCHIVE_O = "\uf1c6";
	static final String ICON_FILE_AUDIO_O = "\uf1c7";
	static final String ICON_FILE_CODE_O = "\uf1c9";
	static final String ICON_FILE_EXCEL_O = "\uf1c3";
	static final String ICON_FILE_IMAGE_O = "\uf1c5";
	static final String ICON_FILE_MOVIE_O = "\uf1c8";
	static final String ICON_FILE_O = "\uf016";
	static final String ICON_FILE_PDF_O = "\uf1c1";
	static final String ICON_FILE_PHOTO_O = "\uf1c5";
	static final String ICON_FILE_PICTURE_O = "\uf1c5";
	static final String ICON_FILE_POWERPOINT_O = "\uf1c4";
	static final String ICON_FILE_SOUND_O = "\uf1c7";
	static final String ICON_FILE_TEXT = "\uf15c";
	static final String ICON_FILE_TEXT_O = "\uf0f6";
	static final String ICON_FILE_VIDEO_O = "\uf1c8";
	static final String ICON_FILE_WORD_O = "\uf1c2";
	static final String ICON_FILE_ZIP_O = "\uf1c6";
	static final String ICON_FILES_O = "\uf0c5";
	static final String ICON_FILM = "\uf008";
	static final String ICON_FILTER = "\uf0b0";
	static final String ICON_FIRE = "\uf06d";
	static final String ICON_FIRE_EXTINGUISHER = "\uf134";
	static final String ICON_FLAG = "\uf024";
	static final String ICON_FLAG_CHECKERED = "\uf11e";
	static final String ICON_FLAG_O = "\uf11d";
	static final String ICON_FLASH = "\uf0e7";
	static final String ICON_FLASK = "\uf0c3";
	static final String ICON_FLICKR = "\uf16e";
	static final String ICON_FLOPPY_O = "\uf0c7";
	static final String ICON_FOLDER = "\uf07b";
	static final String ICON_FOLDER_O = "\uf114";
	static final String ICON_FOLDER_OPEN = "\uf07c";
	static final String ICON_FOLDER_OPEN_O = "\uf115";
	static final String ICON_FONT = "\uf031";
	static final String ICON_FORUMBEE = "\uf211";
	static final String ICON_FORWARD = "\uf04e";
	static final String ICON_FOURSQUARE = "\uf180";
	static final String ICON_FROWN_O = "\uf119";
	static final String ICON_FUTBOL_O = "\uf1e3";
	static final String ICON_GAMEPAD = "\uf11b";
	static final String ICON_GAVEL = "\uf0e3";
	static final String ICON_GBP = "\uf154";
	static final String ICON_GE = "\uf1d1";
	static final String ICON_GEAR = "\uf013";
	static final String ICON_GEARS = "\uf085";
	static final String ICON_GENDERLESS = "\uf1db";
	static final String ICON_GIFT = "\uf06b";
	static final String ICON_GIT = "\uf1d3";
	static final String ICON_GIT_SQUARE = "\uf1d2";
	static final String ICON_GITHUB = "\uf09b";
	static final String ICON_GITHUB_ALT = "\uf113";
	static final String ICON_GITHUB_SQUARE = "\uf092";
	static final String ICON_GITTIP = "\uf184";
	static final String ICON_GLASS = "\uf000";
	static final String ICON_GLOBE = "\uf0ac";
	static final String ICON_GOOGLE = "\uf1a0";
	static final String ICON_GOOGLE_PLUS = "\uf0d5";
	static final String ICON_GOOGLE_PLUS_SQUARE = "\uf0d4";
	static final String ICON_GOOGLE_WALLET = "\uf1ee";
	static final String ICON_GRADUATION_CAP = "\uf19d";
	static final String ICON_GRATIPAY = "\uf184";
	static final String ICON_GROUP = "\uf0c0";
	static final String ICON_H_SQUARE = "\uf0fd";
	static final String ICON_HACKER_NEWS = "\uf1d4";
	static final String ICON_HAND_O_DOWN = "\uf0a7";
	static final String ICON_HAND_O_LEFT = "\uf0a5";
	static final String ICON_HAND_O_RIGHT = "\uf0a4";
	static final String ICON_HAND_O_UP = "\uf0a6";
	static final String ICON_HDD_O = "\uf0a0";
	static final String ICON_HEADER = "\uf1dc";
	static final String ICON_HEADPHONES = "\uf025";
	static final String ICON_HEART = "\uf004";
	static final String ICON_HEART_O = "\uf08a";
	static final String ICON_HEARTBEAT = "\uf21e";
	static final String ICON_HISTORY = "\uf1da";
	static final String ICON_HOME = "\uf015";
	static final String ICON_HOSPITAL_O = "\uf0f8";
	static final String ICON_HOTEL = "\uf236";
	static final String ICON_HOURGLASS = "\uf254";
	static final String ICON_HOURGLASS_1 = "\uf251";
	static final String ICON_HOURGLASS_2 = "\uf252";
	static final String ICON_HOURGLASS_3 = "\uf253";
	static final String ICON_HOURGLASS_END = "\uf253";
	static final String ICON_HOURGLASS_HALF = "\uf252";
	static final String ICON_HOURGLASS_O = "\uf250";
	static final String ICON_HOURGLASS_START = "\uf251";
	static final String ICON_HTML5 = "\uf13b";
	static final String ICON_ILS = "\uf20b";
	static final String ICON_IMAGE = "\uf03e";
	static final String ICON_INBOX = "\uf01c";
	static final String ICON_INDENT = "\uf03c";
	static final String ICON_INFO = "\uf129";
	static final String ICON_INFO_CIRCLE = "\uf05a";
	static final String ICON_INR = "\uf156";
	static final String ICON_INSTAGRAM = "\uf16d";
	static final String ICON_INSTITUTION = "\uf19c";
	static final String ICON_IOXHOST = "\uf208";
	static final String ICON_ITALIC = "\uf033";
	static final String ICON_JOOMLA = "\uf1aa";
	static final String ICON_JPY = "\uf157";
	static final String ICON_JSFIDDLE = "\uf1cc";
	static final String ICON_KEY = "\uf084";
	static final String ICON_KEYBOARD_O = "\uf11c";
	static final String ICON_KRW = "\uf159";
	static final String ICON_LANGUAGE = "\uf1ab";
	static final String ICON_LAPTOP = "\uf109";
	static final String ICON_LASTFM = "\uf202";
	static final String ICON_LASTFM_SQUARE = "\uf203";
	static final String ICON_LEAF = "\uf06c";
	static final String ICON_LEANPUB = "\uf212";
	static final String ICON_LEGAL = "\uf0e3";
	static final String ICON_LEMON_O = "\uf094";
	static final String ICON_LEVEL_DOWN = "\uf149";
	static final String ICON_LEVEL_UP = "\uf148";
	static final String ICON_LIFE_BOUY = "\uf1cd";
	static final String ICON_LIFE_BUOY = "\uf1cd";
	static final String ICON_LIFE_RING = "\uf1cd";
	static final String ICON_LIFE_SAVER = "\uf1cd";
	static final String ICON_LIGHTBULB_O = "\uf0eb";
	static final String ICON_LINE_CHART = "\uf201";
	static final String ICON_LINK = "\uf0c1";
	static final String ICON_LINKEDIN = "\uf0e1";
	static final String ICON_LINKEDIN_SQUARE = "\uf08c";
	static final String ICON_LINUX = "\uf17c";
	static final String ICON_LIST = "\uf03a";
	static final String ICON_LIST_ALT = "\uf022";
	static final String ICON_LIST_OL = "\uf0cb";
	static final String ICON_LIST_UL = "\uf0ca";
	static final String ICON_LOCATION_ARROW = "\uf124";
	static final String ICON_LOCK = "\uf023";
	static final String ICON_LONG_ARROW_DOWN = "\uf175";
	static final String ICON_LONG_ARROW_LEFT = "\uf177";
	static final String ICON_LONG_ARROW_RIGHT = "\uf178";
	static final String ICON_LONG_ARROW_UP = "\uf176";
	static final String ICON_MAGIC = "\uf0d0";
	static final String ICON_MAGNET = "\uf076";
	static final String ICON_MAIL_FORWARD = "\uf064";
	static final String ICON_MAIL_REPLY = "\uf112";
	static final String ICON_MAIL_REPLY_ALL = "\uf122";
	static final String ICON_MALE = "\uf183";
	static final String ICON_MAP_MARKER = "\uf041";
	static final String ICON_MARS = "\uf222";
	static final String ICON_MARS_DOUBLE = "\uf227";
	static final String ICON_MARS_STROKE = "\uf229";
	static final String ICON_MARS_STROKE_H = "\uf22b";
	static final String ICON_MARS_STROKE_V = "\uf22a";
	static final String ICON_MAXCDN = "\uf136";
	static final String ICON_MEANPATH = "\uf20c";
	static final String ICON_MEDIUM = "\uf23a";
	static final String ICON_MEDKIT = "\uf0fa";
	static final String ICON_MEH_O = "\uf11a";
	static final String ICON_MERCURY = "\uf223";
	static final String ICON_MICROPHONE = "\uf130";
	static final String ICON_MICROPHONE_SLASH = "\uf131";
	static final String ICON_MINUS = "\uf068";
	static final String ICON_MINUS_CIRCLE = "\uf056";
	static final String ICON_MINUS_SQUARE = "\uf146";
	static final String ICON_MINUS_SQUARE_O = "\uf147";
	static final String ICON_MOBILE = "\uf10b";
	static final String ICON_MOBILE_PHONE = "\uf10b";
	static final String ICON_MONEY = "\uf0d6";
	static final String ICON_MOON_O = "\uf186";
	static final String ICON_MORTAR_BOARD = "\uf19d";
	static final String ICON_MOTORCYCLE = "\uf21c";
	static final String ICON_MUSIC = "\uf001";
	static final String ICON_NAVICON = "\uf0c9";
	static final String ICON_NEUTER = "\uf22c";
	static final String ICON_NEWSPAPER_O = "\uf1ea";
	static final String ICON_OPENID = "\uf19b";
	static final String ICON_OUTDENT = "\uf03b";
	static final String ICON_PAGELINES = "\uf18c";
	static final String ICON_PAINT_BRUSH = "\uf1fc";
	static final String ICON_PAPER_PLANE = "\uf1d8";
	static final String ICON_PAPER_PLANE_O = "\uf1d9";
	static final String ICON_PAPERCLIP = "\uf0c6";
	static final String ICON_PARAGRAPH = "\uf1dd";
	static final String ICON_PASTE = "\uf0ea";
	static final String ICON_PAUSE = "\uf04c";
	static final String ICON_PAW = "\uf1b0";
	static final String ICON_PAYPAL = "\uf1ed";
	static final String ICON_PENCIL = "\uf040";
	static final String ICON_PENCIL_SQUARE = "\uf14b";
	static final String ICON_PENCIL_SQUARE_O = "\uf044";
	static final String ICON_PHONE = "\uf095";
	static final String ICON_PHONE_SQUARE = "\uf098";
	static final String ICON_PHOTO = "\uf03e";
	static final String ICON_PICTURE_O = "\uf03e";
	static final String ICON_PIE_CHART = "\uf200";
	static final String ICON_PIED_PIPER = "\uf1a7";
	static final String ICON_PIED_PIPER_ALT = "\uf1a8";
	static final String ICON_PINTEREST = "\uf0d2";
	static final String ICON_PINTEREST_P = "\uf231";
	static final String ICON_PINTEREST_SQUARE = "\uf0d3";
	static final String ICON_PLANE = "\uf072";
	static final String ICON_PLAY = "\uf04b";
	static final String ICON_PLAY_CIRCLE = "\uf144";
	static final String ICON_PLAY_CIRCLE_O = "\uf01d";
	static final String ICON_PLUG = "\uf1e6";
	static final String ICON_PLUS = "\uf067";
	static final String ICON_PLUS_CIRCLE = "\uf055";
	static final String ICON_PLUS_SQUARE = "\uf0fe";
	static final String ICON_PLUS_SQUARE_O = "\uf196";
	static final String ICON_POWER_OFF = "\uf011";
	static final String ICON_PRINT = "\uf02f";
	static final String ICON_PUZZLE_PIECE = "\uf12e";
	static final String ICON_QQ = "\uf1d6";
	static final String ICON_QRCODE = "\uf029";
	static final String ICON_QUESTION = "\uf128";
	static final String ICON_QUESTION_CIRCLE = "\uf059";
	static final String ICON_QUOTE_LEFT = "\uf10d";
	static final String ICON_QUOTE_RIGHT = "\uf10e";
	static final String ICON_RA = "\uf1d0";
	static final String ICON_RANDOM = "\uf074";
	static final String ICON_REBEL = "\uf1d0";
	static final String ICON_RECYCLE = "\uf1b8";
	static final String ICON_REDDIT = "\uf1a1";
	static final String ICON_REDDIT_SQUARE = "\uf1a2";
	static final String ICON_REFRESH = "\uf021";
	static final String ICON_REMOVE = "\uf00d";
	static final String ICON_RENREN = "\uf18b";
	static final String ICON_REORDER = "\uf0c9";
	static final String ICON_REPEAT = "\uf01e";
	static final String ICON_REPLY = "\uf112";
	static final String ICON_REPLY_ALL = "\uf122";
	static final String ICON_RETWEET = "\uf079";
	static final String ICON_RMB = "\uf157";
	static final String ICON_ROAD = "\uf018";
	static final String ICON_ROCKET = "\uf135";
	static final String ICON_ROTATE_LEFT = "\uf0e2";
	static final String ICON_ROTATE_RIGHT = "\uf01e";
	static final String ICON_ROUBLE = "\uf158";
	static final String ICON_RSS = "\uf09e";
	static final String ICON_RSS_SQUARE = "\uf143";
	static final String ICON_RUB = "\uf158";
	static final String ICON_RUBLE = "\uf158";
	static final String ICON_RUPEE = "\uf156";
	static final String ICON_SAVE = "\uf0c7";
	static final String ICON_SCISSORS = "\uf0c4";
	static final String ICON_SEARCH = "\uf002";
	static final String ICON_SEARCH_MINUS = "\uf010";
	static final String ICON_SEARCH_PLUS = "\uf00e";
	static final String ICON_SELLSY = "\uf213";
	static final String ICON_SEND = "\uf1d8";
	static final String ICON_SEND_O = "\uf1d9";
	static final String ICON_SERVER = "\uf233";
	static final String ICON_SHARE = "\uf064";
	static final String ICON_SHARE_ALT = "\uf1e0";
	static final String ICON_SHARE_ALT_SQUARE = "\uf1e1";
	static final String ICON_SHARE_SQUARE = "\uf14d";
	static final String ICON_SHARE_SQUARE_O = "\uf045";
	static final String ICON_SHEKEL = "\uf20b";
	static final String ICON_SHEQEL = "\uf20b";
	static final String ICON_SHIELD = "\uf132";
	static final String ICON_SHIP = "\uf21a";
	static final String ICON_SHIRTSINBULK = "\uf214";
	static final String ICON_SHOPPING_CART = "\uf07a";
	static final String ICON_SIGN_IN = "\uf090";
	static final String ICON_SIGN_OUT = "\uf08b";
	static final String ICON_SIGNAL = "\uf012";
	static final String ICON_SIMPLYBUILT = "\uf215";
	static final String ICON_SITEMAP = "\uf0e8";
	static final String ICON_SKYATLAS = "\uf216";
	static final String ICON_SKYPE = "\uf17e";
	static final String ICON_SLACK = "\uf198";
	static final String ICON_SLIDERS = "\uf1de";
	static final String ICON_SLIDESHARE = "\uf1e7";
	static final String ICON_SMILE_O = "\uf118";
	static final String ICON_SOCCER_BALL_O = "\uf1e3";
	static final String ICON_SORT = "\uf0dc";
	static final String ICON_SORT_ALPHA_ASC = "\uf15d";
	static final String ICON_SORT_ALPHA_DESC = "\uf15e";
	static final String ICON_SORT_AMOUNT_ASC = "\uf160";
	static final String ICON_SORT_AMOUNT_DESC = "\uf161";
	static final String ICON_SORT_ASC = "\uf0de";
	static final String ICON_SORT_DESC = "\uf0dd";
	static final String ICON_SORT_DOWN = "\uf0dd";
	static final String ICON_SORT_NUMERIC_ASC = "\uf162";
	static final String ICON_SORT_NUMERIC_DESC = "\uf163";
	static final String ICON_SORT_UP = "\uf0de";
	static final String ICON_SOUNDCLOUD = "\uf1be";
	static final String ICON_SPACE_SHUTTLE = "\uf197";
	static final String ICON_SPINNER = "\uf110";
	static final String ICON_SPOON = "\uf1b1";
	static final String ICON_SPOTIFY = "\uf1bc";
	static final String ICON_SQUARE = "\uf0c8";
	static final String ICON_SQUARE_O = "\uf096";
	static final String ICON_STACK_EXCHANGE = "\uf18d";
	static final String ICON_STACK_OVERFLOW = "\uf16c";
	static final String ICON_STAR = "\uf005";
	static final String ICON_STAR_HALF = "\uf089";
	static final String ICON_STAR_HALF_EMPTY = "\uf123";
	static final String ICON_STAR_HALF_FULL = "\uf123";
	static final String ICON_STAR_HALF_O = "\uf123";
	static final String ICON_STAR_O = "\uf006";
	static final String ICON_STEAM = "\uf1b6";
	static final String ICON_STEAM_SQUARE = "\uf1b7";
	static final String ICON_STEP_BACKWARD = "\uf048";
	static final String ICON_STEP_FORWARD = "\uf051";
	static final String ICON_STETHOSCOPE = "\uf0f1";
	static final String ICON_STOP = "\uf04d";
	static final String ICON_STREET_VIEW = "\uf21d";
	static final String ICON_STRIKETHROUGH = "\uf0cc";
	static final String ICON_STUMBLEUPON = "\uf1a4";
	static final String ICON_STUMBLEUPON_CIRCLE = "\uf1a3";
	static final String ICON_SUBSCRIPT = "\uf12c";
	static final String ICON_SUBWAY = "\uf239";
	static final String ICON_SUITCASE = "\uf0f2";
	static final String ICON_SUN_O = "\uf185";
	static final String ICON_SUPERSCRIPT = "\uf12b";
	static final String ICON_SUPPORT = "\uf1cd";
	static final String ICON_TABLE = "\uf0ce";
	static final String ICON_TABLET = "\uf10a";
	static final String ICON_TACHOMETER = "\uf0e4";
	static final String ICON_TAG = "\uf02b";
	static final String ICON_TAGS = "\uf02c";
	static final String ICON_TASKS = "\uf0ae";
	static final String ICON_TAXI = "\uf1ba";
	static final String ICON_TENCENT_WEIBO = "\uf1d5";
	static final String ICON_TERMINAL = "\uf120";
	static final String ICON_TEXT_HEIGHT = "\uf034";
	static final String ICON_TEXT_WIDTH = "\uf035";
	static final String ICON_TH = "\uf00a";
	static final String ICON_TH_LARGE = "\uf009";
	static final String ICON_TH_LIST = "\uf00b";
	static final String ICON_THUMB_TACK = "\uf08d";
	static final String ICON_THUMBS_DOWN = "\uf165";
	static final String ICON_THUMBS_O_DOWN = "\uf088";
	static final String ICON_THUMBS_O_UP = "\uf087";
	static final String ICON_THUMBS_UP = "\uf164";
	static final String ICON_TICKET = "\uf145";
	static final String ICON_TIMES = "\uf00d";
	static final String ICON_TIMES_CIRCLE = "\uf057";
	static final String ICON_TIMES_CIRCLE_O = "\uf05c";
	static final String ICON_TINT = "\uf043";
	static final String ICON_TOGGLE_DOWN = "\uf150";
	static final String ICON_TOGGLE_LEFT = "\uf191";
	static final String ICON_TOGGLE_OFF = "\uf204";
	static final String ICON_TOGGLE_ON = "\uf205";
	static final String ICON_TOGGLE_RIGHT = "\uf152";
	static final String ICON_TOGGLE_UP = "\uf151";
	static final String ICON_TRAIN = "\uf238";
	static final String ICON_TRANSGENDER = "\uf224";
	static final String ICON_TRANSGENDER_ALT = "\uf225";
	static final String ICON_TRASH = "\uf1f8";
	static final String ICON_TRASH_O = "\uf014";
	static final String ICON_TREE = "\uf1bb";
	static final String ICON_TRELLO = "\uf181";
	static final String ICON_TROPHY = "\uf091";
	static final String ICON_TRUCK = "\uf0d1";
	static final String ICON_TRY = "\uf195";
	static final String ICON_TTY = "\uf1e4";
	static final String ICON_TUMBLR = "\uf173";
	static final String ICON_TUMBLR_SQUARE = "\uf174";
	static final String ICON_TURKISH_LIRA = "\uf195";
	static final String ICON_TWITCH = "\uf1e8";
	static final String ICON_TWITTER = "\uf099";
	static final String ICON_TWITTER_SQUARE = "\uf081";
	static final String ICON_UMBRELLA = "\uf0e9";
	static final String ICON_UNDERLINE = "\uf0cd";
	static final String ICON_UNDO = "\uf0e2";
	static final String ICON_UNIVERSITY = "\uf19c";
	static final String ICON_UNLINK = "\uf127";
	static final String ICON_UNLOCK = "\uf09c";
	static final String ICON_UNLOCK_ALT = "\uf13e";
	static final String ICON_UNSORTED = "\uf0dc";
	static final String ICON_UPLOAD = "\uf093";
	static final String ICON_USD = "\uf155";
	static final String ICON_USER = "\uf007";
	static final String ICON_USER_MD = "\uf0f0";
	static final String ICON_USER_PLUS = "\uf234";
	static final String ICON_USER_SECRET = "\uf21b";
	static final String ICON_USER_TIMES = "\uf235";
	static final String ICON_USERS = "\uf0c0";
	static final String ICON_VENUS = "\uf221";
	static final String ICON_VENUS_DOUBLE = "\uf226";
	static final String ICON_VENUS_MARS = "\uf228";
	static final String ICON_VIACOIN = "\uf237";
	static final String ICON_VIDEO_CAMERA = "\uf03d";
	static final String ICON_VIMEO_SQUARE = "\uf194";
	static final String ICON_VINE = "\uf1ca";
	static final String ICON_VK = "\uf189";
	static final String ICON_VOLUME_DOWN = "\uf027";
	static final String ICON_VOLUME_OFF = "\uf026";
	static final String ICON_VOLUME_UP = "\uf028";
	static final String ICON_WARNING = "\uf071";
	static final String ICON_WECHAT = "\uf1d7";
	static final String ICON_WEIBO = "\uf18a";
	static final String ICON_WEIXIN = "\uf1d7";
	static final String ICON_WHATSAPP = "\uf232";
	static final String ICON_WHEELCHAIR = "\uf193";
	static final String ICON_WIFI = "\uf1eb";
	static final String ICON_WINDOWS = "\uf17a";
	static final String ICON_WON = "\uf159";
	static final String ICON_WORDPRESS = "\uf19a";
	static final String ICON_WRENCH = "\uf0ad";
	static final String ICON_XING = "\uf168";
	static final String ICON_XING_SQUARE = "\uf169";
	static final String ICON_YAHOO = "\uf19e";
	static final String ICON_YELP = "\uf1e9";
	static final String ICON_YEN = "\uf157";
	static final String ICON_YOUTUBE = "\uf167";
	static final String ICON_YOUTUBE_PLAY = "\uf16a";
	static final String ICON_YOUTUBE_SQUARE = "\uf166";
	static final String ICON_PIED_PIPER_PP = "\uF1A7";
	static final String ICON_Y_COMBINATOR = "\uF23B";
	static final String ICON_OPTIN_MONSTER = "\uF23C";
	static final String ICON_OPENCART = "\uF23D";
	static final String ICON_EXPEDITEDSSL = "\uF23E";
	static final String ICON_BATTERY_FULL = "\uF240";
	static final String ICON_BATTERY_THREE_QUARTERS = "\uF241";
	static final String ICON_BATTERY_HALF = "\uF242";
	static final String ICON_BATTERY_QUARTER = "\uF243";
	static final String ICON_BATTERY_EMPTY = "\uF244";
	static final String ICON_MOUSE_POINTER = "\uF245";
	static final String ICON_I_CURSOR = "\uF246";
	static final String ICON_OBJECT_GROUP = "\uF247";
	static final String ICON_OBJECT_UNGROUP = "\uF248";
	static final String ICON_STICKY_NOTE = "\uF249";
	static final String ICON_STICKY_NOTE_O = "\uF24A";
	static final String ICON_CC_JCB = "\uF24B";
	static final String ICON_CC_DINERS_CLUB = "\uF24C";
	static final String ICON_CLONE = "\uF24D";
	static final String ICON_BALANCE_SCALE = "\uF24E";
	static final String ICON_HAND_ROCK_O = "\uF255";
	static final String ICON_HAND_PAPER_O = "\uF256";
	static final String ICON_HAND_SCISSORS_O = "\uF257";
	static final String ICON_HAND_LIZARD_O = "\uF258";
	static final String ICON_HAND_SPOCK_O = "\uF259";
	static final String ICON_HAND_POINTER_O = "\uF25A";
	static final String ICON_HAND_PEACE_O = "\uF25B";
	static final String ICON_TRADEMARK = "\uF25C";
	static final String ICON_REGISTERED = "\uF25D";
	static final String ICON_CREATIVE_COMMONS = "\uF25E";
	static final String ICON_GG = "\uF260";
	static final String ICON_GG_CIRCLE = "\uF261";
	static final String ICON_TRIPADVISOR = "\uF262";
	static final String ICON_ODNOKLASSNIKI = "\uF263";
	static final String ICON_ODNOKLASSNIKI_SQUARE = "\uF264";
	static final String ICON_GET_POCKET = "\uF265";
	static final String ICON_WIKIPEDIA_W = "\uF266";
	static final String ICON_SAFARI = "\uF267";
	static final String ICON_CHROME = "\uF268";
	static final String ICON_FIREFOX = "\uF269";
	static final String ICON_OPERA = "\uF26A";
	static final String ICON_INTERNET_EXPLORER = "\uF26B";
	static final String ICON_TELEVISION = "\uF26C";
	static final String ICON_CONTAO = "\uF26D";
	static final String ICON_500PX = "\uF26E";
	static final String ICON_AMAZON = "\uF270";
	static final String ICON_CALENDAR_PLUS_O = "\uF271";
	static final String ICON_CALENDAR_MINUS_O = "\uF272";
	static final String ICON_CALENDAR_TIMES_O = "\uF273";
	static final String ICON_CALENDAR_CHECK_O = "\uF274";
	static final String ICON_INDUSTRY = "\uF275";
	static final String ICON_MAP_PIN = "\uF276";
	static final String ICON_MAP_SIGNS = "\uF277";
	static final String ICON_MAP_O = "\uF278";
	static final String ICON_MAP = "\uF279";
	static final String ICON_COMMENTING = "\uF27A";
	static final String ICON_COMMENTING_O = "\uF27B";
	static final String ICON_HOUZZ = "\uF27C";
	static final String ICON_VIMEO = "\uF27D";
	static final String ICON_BLACK_TIE = "\uF27E";
	static final String ICON_FONTICONS = "\uF280";
	static final String ICON_REDDIT_ALIEN = "\uF281";
	static final String ICON_EDGE = "\uF282";
	static final String ICON_CREDIT_CARD_ALT = "\uF283";
	static final String ICON_CODIEPIE = "\uF284";
	static final String ICON_MODX = "\uF285";
	static final String ICON_FORT_AWESOME = "\uF286";
	static final String ICON_USB = "\uF287";
	static final String ICON_PRODUCT_HUNT = "\uF288";
	static final String ICON_MIXCLOUD = "\uF289";
	static final String ICON_SCRIBD = "\uF28A";
	static final String ICON_PAUSE_CIRCLE = "\uF28B";
	static final String ICON_PAUSE_CIRCLE_O = "\uF28C";
	static final String ICON_STOP_CIRCLE = "\uF28D";
	static final String ICON_STOP_CIRCLE_O = "\uF28E";
	static final String ICON_SHOPPING_BAG = "\uF290";
	static final String ICON_SHOPPING_BASKET = "\uF291";
	static final String ICON_HASHTAG = "\uF292";
	static final String ICON_BLUETOOTH = "\uF293";
	static final String ICON_BLUETOOTH_B = "\uF294";
	static final String ICON_PERCENT = "\uF295";
	static final String ICON_GITLAB = "\uF296";
	static final String ICON_WPBEGINNER = "\uF297";
	static final String ICON_WPFORMS = "\uF298";
	static final String ICON_ENVIRA = "\uF299";
	static final String ICON_UNIVERSAL_ACCESS = "\uF29A";
	static final String ICON_WHEELCHAIR_ALT = "\uF29B";
	static final String ICON_QUESTION_CIRCLE_O = "\uF29C";
	static final String ICON_BLIND = "\uF29D";
	static final String ICON_AUDIO_DESCRIPTION = "\uF29E";
	static final String ICON_VOLUME_CONTROL_PHONE = "\uF2A0";
	static final String ICON_BRAILLE = "\uF2A1";
	static final String ICON_ASSISTIVE_LISTENING_SYSTEMS = "\uF2A2";
	static final String ICON_AMERICAN_SIGN_LANGUAGE_INTERPRETING = "\uF2A3";
	static final String ICON_DEAF = "\uF2A4";
	static final String ICON_GLIDE = "\uF2A5";
	static final String ICON_GLIDE_G = "\uF2A6";
	static final String ICON_SIGN_LANGUAGE = "\uF2A7";
	static final String ICON_LOW_VISION = "\uF2A8";
	static final String ICON_VIADEO = "\uF2A9";
	static final String ICON_VIADEO_SQUARE = "\uF2AA";
	static final String ICON_SNAPCHAT = "\uF2AB";
	static final String ICON_SNAPCHAT_GHOST = "\uF2AC";
	static final String ICON_SNAPCHAT_SQUARE = "\uF2AD";
	static final String ICON_FIRST_ORDER = "\uF2B0";
	static final String ICON_YOAST = "\uF2B1";
	static final String ICON_THEMEISLE = "\uF2B2";
	static final String ICON_GOOGLE_PLUS_OFFICIAL = "\uF2B3";
	static final String ICON_FONT_AWESOME = "\uF2B4";
	static final String ICON_HANDSHAKE_O = "\uF2B5";
	static final String ICON_ENVELOPE_OPEN = "\uF2B6";
	static final String ICON_ENVELOPE_OPEN_O = "\uF2B7";
	static final String ICON_LINODE = "\uF2B8";
	static final String ICON_ADDRESS_BOOK = "\uF2B9";
	static final String ICON_ADDRESS_BOOK_O = "\uF2BA";
	static final String ICON_ADDRESS_CARD = "\uF2BB";
	static final String ICON_ADDRESS_CARD_O = "\uF2BC";
	static final String ICON_USER_CIRCLE = "\uF2BD";
	static final String ICON_USER_CIRCLE_O = "\uF2BE";
	static final String ICON_USER_O = "\uF2C0";
	static final String ICON_ID_BADGE = "\uF2C1";
	static final String ICON_ID_CARD = "\uF2C2";
	static final String ICON_ID_CARD_O = "\uF2C3";
	static final String ICON_QUORA = "\uF2C4";
	static final String ICON_FREE_CODE_CAMP = "\uF2C5";
	static final String ICON_TELEGRAM = "\uF2C6";
	static final String ICON_THERMOMETER_FULL = "\uF2C7";
	static final String ICON_THERMOMETER_THREE_QUARTERS = "\uF2C8";
	static final String ICON_THERMOMETER_HALF = "\uF2C9";
	static final String ICON_THERMOMETER_QUARTER = "\uF2CA";
	static final String ICON_THERMOMETER_EMPTY = "\uF2CB";
	static final String ICON_SHOWER = "\uF2CC";
	static final String ICON_BATH = "\uF2CD";
	static final String ICON_PODCAST = "\uF2CE";
	static final String ICON_WINDOW_MAXIMIZE = "\uF2D0";
	static final String ICON_WINDOW_MINIMIZE = "\uF2D1";
	static final String ICON_WINDOW_RESTORE = "\uF2D2";
	static final String ICON_WINDOW_CLOSE = "\uF2D3";
	static final String ICON_WINDOW_CLOSE_O = "\uF2D4";
	static final String ICON_BANDCAMP = "\uF2D5";
	static final String ICON_GRAV = "\uF2D6";
	static final String ICON_ETSY = "\uF2D7";
	static final String ICON_IMDB = "\uF2D8";
	static final String ICON_RAVELRY = "\uF2D9";
	static final String ICON_EERCAST = "\uF2DA";
	static final String ICON_MICROCHIP = "\uF2DB";
	static final String ICON_SNOWFLAKE_O = "\uF2DC";
	static final String ICON_SUPERPOWERS = "\uF2DD";
	static final String ICON_WPEXPLORER = "\uF2DE";
	static final String ICON_MEETUP = "\uF2E0";

}
